@@ -12,13 +12,14 @@ with qw/
   /;
 
 use List::Util  1.33 qw/ any /;
+use File::ShareDir (); # needed by Module::Manifest::Skip v0.23
 use Module::Manifest::Skip ();
 use MooseX::MungeHas;
 use Types::Standard -types;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.1.2';
 
 
 sub mvp_multivalue_args { qw/ add remove / }
@@ -103,7 +104,7 @@ Dist::Zilla::Plugin::Generate::ManifestSkip - generate a MANIFEST.SKIP file for
 
 =head1 VERSION
 
-version v0.1.1
+version v0.1.2
 
 =head1 DESCRIPTION
 
@@ -126,13 +127,13 @@ By defaut, the following files are added to the skipfile:
 
 =item C<\.build/>
 
-=item C<{$dist->name}-.*/>
+=item C<{$dist_name}-.*/>
 
-=item C<{$dist->name}-.*\.tar\.gz>
+=item C<{$dist_name}-.*\.tar\.gz>
 
 =back
 
-where C<$dist->name> is the name of the distribution.
+where C<$dist_name> is the name of the distribution.
 
 If the distribution has an F<alienfile>, then C<_alien/> will be added,
 
